@@ -4,11 +4,11 @@ use std::io::{Cursor, ErrorKind};
 pub mod linear_algebra;
 pub mod simulation;
 
-use linear_algebra::vector::Vec3;
 use simulation::ball::Ball;
-use simulation::field::{initialize_soccar, initialize_dropshot, initialize_hoops, initialize_throwback};
+use simulation::field::{initialize_dropshot, initialize_hoops, initialize_soccar, initialize_throwback};
 use simulation::game::Game;
 use simulation::mesh::Mesh;
+use vvec3::Vec3;
 
 fn read_mesh(ids_dat: Vec<u8>, vertices_dat: Vec<u8>) -> Mesh {
     let mut ids_dat = Cursor::new(ids_dat);
@@ -56,11 +56,7 @@ pub fn load_soccar() -> Game {
 
     let ball = Ball::initialize_soccar();
 
-    let gravity = Vec3 {
-        x: 0.,
-        y: 0.,
-        z: -650.,
-    };
+    let gravity = Vec3::new(0., 0., -650.);
 
     Game {
         gravity,
@@ -80,11 +76,7 @@ pub fn load_hoops() -> Game {
 
     let ball = Ball::initialize_hoops();
 
-    let gravity = Vec3 {
-        x: 0.,
-        y: 0.,
-        z: -650.,
-    };
+    let gravity = Vec3::new(0., 0., -650.);
 
     Game {
         gravity,
@@ -100,11 +92,7 @@ pub fn load_dropshot() -> Game {
 
     let ball = Ball::initialize_dropshot();
 
-    let gravity = Vec3 {
-        x: 0.,
-        y: 0.,
-        z: -650.,
-    };
+    let gravity = Vec3::new(0., 0., -650.);
 
     Game {
         gravity,
@@ -131,11 +119,7 @@ pub fn load_soccar_throwback() -> Game {
 
     let ball = Ball::initialize_soccar();
 
-    let gravity = Vec3 {
-        x: 0.,
-        y: 0.,
-        z: -650.,
-    };
+    let gravity = Vec3::new(0., 0., -650.);
 
     Game {
         gravity,
